// Author : Pierre Vuillemin (2016)
// License : CECILL

function problem = sopi_min(fun, varargin)
   // Creates an optimisation problem.
   //
   // Calling Sequence
   // problem = sopi_min(fun)
   // problem = sopi_min(fun, c1, ..., cn)
   //
   // Parameters
   // fun: a sopiVar representing the objective function
   // ci: constraints given as sopiCst or list of sopiCst
   // problem: a sopiPro representing the optimisation problem
   //
   if ~isscalar(fun) then
      error("Multi-objective optimisation is not handled")
   end
   cList = list()
   for c = varargin
      if typeof(c) == "sopiCst" then
         cList($+1) = c;
      elseif typeof(c) == "list" then
         cList = lstcat(cList, c)
      else
         error("Unexpected input")
      end
   end
   //
   problem = sopi_newProblem()
   problem = sopi_addAllVar(problem, fun, cList)
   problem = sopi_addObjective(problem, fun)
   problem = sopi_addConstraints(problem, cList)
   
   if problem.objType == 0 & and(problem.cType == 0) then
      problem.class = 0
   end
endfunction
